﻿using System;
using System.Collections.Generic;
using System.Text;

using Com.Piwigo.Lib.DTO;
using System.Web;
using Com.Piwigo.Lib.Proxy.Response;
using Com.Piwigo.Lib.Proxy.Helper;

namespace Com.Piwigo.Lib.Proxy
{
    static internal class PwgTagsProxy
    {
        /* pwg.tags.add             pwg_tag_add
         * pwg.tags.getAdminList    pwg_tags_getAdminList
         * pwg.tags.getImages       pwg_tags_getImages
         * pwg.tags.getList         pwg_tags_getList
         * */

        static internal PwgTagsProxyResponse pwg_tags_getList(Boolean? sortedByCounter)
        {
            PwgTagsProxyResponse response = null;
            try
            {
                StringBuilder data = new StringBuilder();
                Boolean firstOcc = true;

                PwgProxyReponseHelper.buildQueryFromValue<Boolean>(sortedByCounter, "sort_by_counter", ref firstOcc, data);

                response = PwgGenericProxy<PwgTagsProxyResponse>.Get(
                                PwgConfigProxy.PwgServeurUri,
                                "pwg.tags.getList", data.ToString());
            }
            catch (Exception ex)
            {
                throw new PwgProxyException("pwg_tags_getList", ex);
            }
            return response;

        }

        static internal PwgTagsProxyResponse pwg_tags_getAdminList()
        {
            PwgTagsProxyResponse response = null;
            try
            {
                response = PwgGenericProxy<PwgTagsProxyResponse>.Get(
                                PwgConfigProxy.PwgServeurUri,
                                "pwg.tags.getAdminList", null);
            }
            catch (Exception ex)
            {
                throw new PwgProxyException("pwg_tags_getAdminList", ex);
            }
            return response;

        }

        static internal PwgImagesProxyResponse pwg_tags_getImages(List<Int32> tagsId,		
                                                                    List<String>    tagsUrlName,
                                                                    List<String>    tagsName,
                                                                    Boolean?         tagModeAnd,
                                                                    Int32?           perPage,
                                                                    Int32?           Page,
                                                                    Int32?           Order,
                                                                    Int32?           minRate,
                                                                    Int32?           maxRate,
                                                                    Int32?           minHit,
                                                                    Int32?           maxHit,
                                                                    DateTime?        minDateAvailable,
                                                                    DateTime?        maxDateAvailable,
                                                                    DateTime?        minDateCreated,
                                                                    DateTime?        maxDateCreated,
                                                                    Int32?           minRatio,
                                                                    Int32?           maxRatio,
                                                                    Boolean?         withThumbnail)
        {
            PwgImagesProxyResponse response = null;
            try
            {
                StringBuilder data = new StringBuilder();
                Boolean firstOcc = true;
                data.AppendFormat("method={0}","pwg.tags.getImages");
                firstOcc = false;
                PwgProxyReponseHelper.buildQueryFromArray<Int32>(tagsId, "tag_id", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromArray<String>(tagsUrlName, "tag_url_name", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromArray<String>(tagsName, "tag_name", ref firstOcc, data);

                PwgProxyReponseHelper.buildQueryFromValue<Boolean>(tagModeAnd, "tag_mode_and", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(perPage, "per_page", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(Page, "page", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(Order, "order", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(minRate, "f_min_rate", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(maxRate, "f_max_rate", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(minHit, "f_min_hit", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(maxHit, "f_max_hit", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<DateTime>(minDateAvailable, "f_min_date_available", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<DateTime>(maxDateAvailable, "f_max_date_available", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<DateTime>(minDateCreated, "f_min_date_created", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<DateTime>(maxDateCreated, "f_max_date_created", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(minRatio, "f_min_ratio", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Int32>(maxRatio, "f_max_ratio", ref firstOcc, data);
                PwgProxyReponseHelper.buildQueryFromValue<Boolean>(withThumbnail, "f_with_thumbnail", ref firstOcc, data);

                response = PwgGenericProxy<PwgImagesProxyResponse>.Post(
                                PwgConfigProxy.PwgServeurUri,
                                data.ToString());
            }
            catch (Exception ex)
            {
                throw new PwgProxyException("pwg_tags_getImages", ex);
            }
            return response;

        }
        static internal PwgAddRequestProxyResponse pwg_tag_add(String tagName)
        {
            PwgAddRequestProxyResponse response = null;
            try
            {
                StringBuilder data = new StringBuilder();
                data.Append("method=pwg.tags.add");
                data.Append("&name=" + Uri.EscapeUriString(tagName));

                response = PwgGenericProxy<PwgAddRequestProxyResponse>.Post(
                    PwgConfigProxy.PwgServeurUri,
                    data.ToString());
            }
            catch (Exception ex)
            {
                throw new PwgProxyException("pwg_tag_add", ex);
            }

            return response;
        }

    }

}

